==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ItemwiseStrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
/**
 * @hidden
 */
export let ItemwiseStrategyBasedIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemwiseStrategyBasedIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ItemwiseStrategyBasedIndicatorDescriptionMetadata.a == null) {
                ItemwiseStrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(ItemwiseStrategyBasedIndicatorDescriptionMetadata.a);
            }
            if (a.k(ItemwiseStrategyBasedIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(ItemwiseStrategyBasedIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.b(a);
            a.ac("ItemwiseStrategyBasedIndicator", ItemwiseStrategyBasedIndicatorDescriptionMetadata.a);
        }
    }
    ItemwiseStrategyBasedIndicatorDescriptionMetadata.$t = markType(ItemwiseStrategyBasedIndicatorDescriptionMetadata, 'ItemwiseStrategyBasedIndicatorDescriptionMetadata');
    ItemwiseStrategyBasedIndicatorDescriptionMetadata.a = null;
    return ItemwiseStrategyBasedIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ItemwiseStrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
/**
 * @hidden
 */
export let ItemwiseStrategyBasedIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemwiseStrategyBasedIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ItemwiseStrategyBasedIndicatorDescriptionMetadata.a == null) {
                ItemwiseStrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(ItemwiseStrategyBasedIndicatorDescriptionMetadata.a);
            }
            if (a.k(ItemwiseStrategyBasedIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(ItemwiseStrategyBasedIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.b(a);
            a.ad("ItemwiseStrategyBasedIndicator", ItemwiseStrategyBasedIndicatorDescriptionMetadata.a);
        }
    }
    ItemwiseStrategyBasedIndicatorDescriptionMetadata.$t = markType(ItemwiseStrategyBasedIndicatorDescriptionMetadata, 'ItemwiseStrategyBasedIndicatorDescriptionMetadata');
    ItemwiseStrategyBasedIndicatorDescriptionMetadata.a = null;
    return ItemwiseStrategyBasedIndicatorDescriptionMetadata;
})();
